@@ -6,7 +6,6 @@ from ruleskit import RuleSet
 from tablewriter import TableWriter
 import logging
 
-from .central_model_updaters import central_model_update
 from .configs import CentralConfig
 from .actor import Actor
 from .decorator import emit
@@ -55,7 +54,7 @@ class CentralServer(Actor):
 
     @emit
     def update(self):
-        """Add new rules in aggregated_model to central model's models and updates the rules predictions.
+        """Add new rules in aggregated_model to central model's models.
         If new rules were found, save the updated model to `ifra.central_server.CentralServer`'s 
         *central_configs.central_model_path*.
         
@@ -67,9 +66,19 @@ class CentralServer(Actor):
         aggregated_model = RuleSet()
         aggregated_model.load(self.central_configs.aggregated_model_path)
         self.last_fetch = datetime.now()
+        if self.model is None:
+            self.model = aggregated_model
+        else:
+            for r in aggregated_model:
+                if r in self.model:
+                    logger.warning(
+                        f"Rule '{r}' was aggregated despite being already in the central server. It is ignored, its"
+                        " prediction is discarded."
+                    )
+                else:
+                    self.model.append(r, update_activation=False)
         logger.info(f"Fetched new model from aggregator at {self.last_fetch}")
-        if central_model_update(self.model, aggregated_model):
-            self.model_to_file()
+        self.model_to_file()
 
     @emit
     def model_to_file(self) -> None:
@@ -88,6 +97,8 @@ class CentralServer(Actor):
             path = self.central_configs.central_model_path.parent / f"{name}_{iteration}.csv"
 
         path = path.with_suffix(".csv")
+        if not path.parent.isdir():
+            path.parent.mkdir(parents=True)
         model.save(path)
         model.save(self.central_configs.central_model_path)
         logger.info(f"Saved central model in '{self.central_configs.central_model_path}'")
@@ -115,15 +126,16 @@ class CentralServer(Actor):
             How many seconds between each checks for new nodes models. Default value = 5.
         """
 
-        t = time()
         iterations = 0
+        started = False  # To force at least one loop of the while to trigger
 
         if timeout <= 0:
             logger.warning("You did not specify a timeout for your run. It will last until manually stopped.")
         logger.info(f"Starting central server. Monitoring changes in {self.central_configs.aggregated_model_path}.")
 
-        while time() - t < timeout or timeout <= 0:
-
+        t = time()
+        while time() - t < timeout or timeout <= 0 or started is False:
+            started = True
             if len(self.model) == 0:
                 if self.central_configs.aggregated_model_path.is_file():
                     self.update()
