@@ -276,7 +276,7 @@ class Node(Actor):
             )
         else:
             logger.info(f"Did not find rules in node {self.learning_configs.id}")
-        if self.model is not None:
+        if self.model is not None and self.learning_configs.privacy_proba is not None:
             apply_diff_privacy(ruleset=self.model, y=y, p=self.learning_configs.privacy_proba)
             if len(self.model) == 0:
                 logger.warning("No good rule left in model after applying differential privacy")
